def hello(name):
    """
    In return, Hello, name!.

    """
    return f"Hello, {name}!"

def hello_world():
    """
    In return, Hello, World!.

    """
    return "Hello, World!"

def hi(name):
    """
    In return, Hello, name!.

    """
    return f"Hi, {name}"

def hi_world():
    """
    In return, Hi, World!.

    """
    return "Hi, World!"

def version():
    """
    In return, version number.

    """
    return "2.0.0"
